cd "/Users/.../Dropbox/GWS_replicationarchive/Code_tables"

*log using "EU_Yearly_Strikes.log", replace

***********************************************************************************************************
use "/Users/.../Dropbox/GWS_replicationarchive/Data/EU_Yearly_Strikes.dta", clear
***********************************************************************************************************
tsset _ISO3N_ year, yearly

ssc inst egenmore, replace
egen econ_strike = xtile(dayslost_strike), nquantiles(2) by(_ISO3N_)

fvset base 40 _ISO3N_
fvset base 1 year 
 
* Main Tables (excluding unemployment because corr with debt is rho= 0.587)

cd "/Users/.../Dropbox/3 Results/Tables/Yearly Panel"

* Results (Table 1)

eststo D1a: xtreg d.gen_strike l.gen_strike l.debtToGDP c.l2.bankcrisislv12 d.debtToGDP c.d2.bankcrisislv12 l.Inflation d.Inflation l.govparty d.govparty , cluster(_ISO3N_)
eststo D1b: xtreg d.gen_strike l.gen_strike l.debtToGDP c.l2.bankcrisislv12 d.debtToGDP c.d2.bankcrisislv12 l.Inflation d.Inflation l.govparty d.govparty if year>1995 & country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)
eststo D1c: xtreg d.gen_strike l.gen_strike c.l.debtToGDP##c.d2.bankcrisislv12 c.l2.bankcrisislv12 c.d.debtToGDP l.Inflation d.Inflation l.govparty d.govparty if year>1995 & country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_) 
esttab D1a D1b D1c

* Bewley (Table 1)

gen interaction=l.debtToGDP*d2.bankcrisislv12
eststo D1a: ivreg gen_strike debtToGDP d.debtToGDP l.bankcrisislv12 d2.bankcrisislv12 Inflation d.Inflation govparty d.govparty (d.gen_strike = l.gen_strike  debtToGDP l.debtToGDP bankcrisislv12 l.bankcrisislv12 l2.bankcrisislv12 Inflation l.Inflation govparty l.govparty)
eststo D1b: ivreg gen_strike debtToGDP d.debtToGDP l.bankcrisislv12 d2.bankcrisislv12 Inflation d.Inflation govparty d.govparty (d.gen_strike = l.gen_strike  debtToGDP l.debtToGDP bankcrisislv12 l.bankcrisislv12 l2.bankcrisislv12 Inflation l.Inflation govparty l.govparty) if year>1995 & country!="Denmark" & country!="Sweden" & country!="UK" 
eststo D1c: ivreg gen_strike debtToGDP d.debtToGDP interaction d.interaction l.bankcrisislv12 d2.bankcrisislv12 Inflation d.Inflation govparty d.govparty (d.gen_strike = l.gen_strike interaction l.interaction debtToGDP l.debtToGDP bankcrisislv12 l.bankcrisislv12 l2.bankcrisislv12 Inflation l.Inflation govparty l.govparty) if year>1995 &  country!="Denmark" & country!="Sweden" & country!="UK" 

/* different operationalization -> gen interaction1=l.debtToGDP*l2d.bankcrisislv12 */
/* similar result -> ivreg gen_strike debtToGDP d.debtToGDP interaction1 d.interaction1 l.bankcrisislv12 ld.bankcrisislv12 Inflation d.Inflation govparty d.govparty (d.gen_strike = l.gen_strike interaction1 l.interaction1 debtToGDP l.debtToGDP bankcrisislv12 l.bankcrisislv12 l2.bankcrisislv12 Inflation l.Inflation govparty l.govparty) if year>1995 &  country!="Denmark" & country!="Sweden" & country!="UK" */

/* Additional analyses in the Appendix */
* Unit Root tests

xtunitroot fisher gen_strike, pperron lag(1)
xtunitroot fisher d.gen_strike, pperron lag(1)
xtunitroot fisher bankcrisislv12, pperron lag(1)
xtunitroot fisher d.bankcrisislv12, pperron lag(1)
xtunitroot fisher debtToGDP, pperron lag(1)
xtunitroot fisher d.debtToGDP, pperron lag(1)
xtunitroot fisher gen_strike, dfuller lag(1)
xtunitroot fisher d.gen_strike, dfuller lag(1)
xtunitroot fisher bankcrisislv12, dfuller lag(2)
xtunitroot fisher d.bankcrisislv12, dfuller lag(2)
xtunitroot fisher debtToGDP, dfuller lag(1)
xtunitroot fisher d.debtToGDP, dfuller lag(1)

pperron gen_strike if country=="Austria"
pperron gen_strike if country=="Belgium"
pperron gen_strike if country=="Finland"
pperron gen_strike if country=="France"
pperron gen_strike if country=="Germany"
pperron gen_strike if country=="Greece"
pperron gen_strike if country=="Ireland"
pperron gen_strike if country=="Italy"
pperron gen_strike if country=="Netherlands"
pperron gen_strike if country=="Portugal"
pperron gen_strike if country=="Spain"

* Engle-Granger Cointegration Test
egranger gen_strike bankcrisislv12 debtToGDP Inflation  govparty if country=="Austria", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Belgium", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Denmark", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Germany", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Greece", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Ireland", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Italy", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Netherlands", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Portugal", reg
egranger gen_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Spain", reg
egranger econ_strike bankcrisislv12 debtToGDP  Inflation  govparty if country=="Sweden", reg

* Variance Heteroskedasticity (white noise) tests: a selection of panels
wntestb d.gen_strike if country=="Austria"
wntestb d.gen_strike if country=="France"
wntestb d.gen_strike if country=="Greece"
wntestb d.gen_strike if country=="Italy"
wntestb d.debtToGDP if country=="Austria"
wntestb d.debtToGDP if country=="Germany"
wntestb d.debtToGDP if country=="Greece"
wntestb d.debtToGDP if country=="Italy"


* A.2 Logit ECM

eststo D1a: ologit d.gen_strike l.gen_strike c.l.debtToGDP c.l2.bankcrisislv12 c.d.debtToGDP c.d2.bankcrisislv12 l.Inflation d.Inflation  l.govparty d.govparty ,  cluster(_ISO3N_)
eststo D2a: ologit d.gen_strike l.gen_strike c.l.debtToGDP c.l2.bankcrisislv12 c.d.debtToGDP c.d2.bankcrisislv12 l.Inflation d.Inflation  l.govparty d.govparty  if year> 1995 & country!="Denmark" & country!="Sweden" & country!="UK",  cluster(_ISO3N_)
eststo D3a: ologit d.gen_strike l.gen_strike c.l.debtToGDP##c.d2.bankcrisislv12 c.d.debtToGDP c.l2.bankcrisislv12 l.Inflation d.Inflation  l.govparty d.govparty  if year> 1995 & country!="Denmark" & country!="Sweden" & country!="UK",  cluster(_ISO3N_)

* A.3 Fixed Effects OLS Model

eststo D1: xtreg gen_strike c.l.debtToGDP##c.d2.bankcrisislv12  l.Inflation l.govparty   i.year i._ISO3N_ if year> 1995& country!="Denmark" & country!="Sweden" & country!="UK",  cluster(_ISO3N_)
/* same result */ eststo D2: xtreg gen_strike c.l.debtToGDP##c.d.bankcrisislv12  l.Inflation l.govparty   i.year i._ISO3N_ if year> 1995& country!="Denmark" & country!="Sweden" & country!="UK",  cluster(_ISO3N_)

* A.4 Dichotomous Debt Variable

egen debtcut = cut(debtToGDP), group(4)
gen  debthigh=.
replace debthigh=1 if debtcut==3
replace debthigh=0 if debthigh==.

eststo D1a: xtreg d.gen_strike l.gen_strike c.l.debthigh c.l2.bankcrisislv12 c.d.debthigh c.d2.bankcrisislv12 l.Inflation d.Inflation  l.govparty d.govparty , cluster(_ISO3N_)
*eststo D1b: xtreg d.gen_strike l.gen_strike  c.l.debthigh c.l2.bankcrisislv12 c.d.debthigh c.d2.bankcrisislv12  l.Inflation d.Inflation l.govparty d.govparty if year> 1995 & country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)
eststo D1b: xtreg d.gen_strike l.gen_strike  c.l.debthigh##c.d2.bankcrisislv12 c.d.debthigh c.l2.bankcrisislv12  l.Inflation d.Inflation l.govparty d.govparty if year> 1995 & country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)

* A.5 Pre- and Post-1999 Period

eststo D1a: xtreg d.gen_strike l.gen_strike l.debtToGDP c.l2.bankcrisislv12 d.debtToGDP d2.bankcrisislv12  l.Inflation d.Inflation l.govparty d.govparty if year<=1999 , cluster(_ISO3N_)
*eststo D1b: xtreg d.gen_strike l.gen_strike l.debtToGDP c.l2.bankcrisislv12 d.debtToGDP d2.bankcrisislv12  l.Inflation d.Inflation l.govparty d.govparty if year>1999 & country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)
eststo D1c: xtreg d.gen_strike l.gen_strike c.l.debtToGDP##c.d2.bankcrisislv12 d.debtToGDP l2.bankcrisislv12  l.Inflation d.Inflation l.govparty d.govparty if year>1999 & country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)

* A.6 Trade Union Characteristics

eststo D1a: xtreg d.gen_strike l.gen_strike l.debtToGDP c.l2.bankcrisislv12 d.debtToGDP d2.bankcrisislv12 l.ud d.ud  l.Inflation d.Inflation l.govparty d.govparty , cluster(_ISO3N_)
*eststo D1b: xtreg d.gen_strike l.gen_strike l.debtToGDP c.l2.bankcrisislv12 d.debtToGDP d2.bankcrisislv12 l.ud d.ud  l.Inflation d.Inflation l.govparty d.govparty if year> 1995& country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)
eststo D1c: xtreg d.gen_strike l.gen_strike c.l.debtToGDP##c.d2.bankcrisislv12 d.debtToGDP l2.bankcrisislv12 l.ud d.ud  l.Inflation d.Inflation l.govparty d.govparty if year> 1995& country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)

* A.7 Greece Excluded

eststo D1a: xtreg d.gen_strike l.gen_strike c.l.debtToGDP##c.d2.bankcrisislv12 c.l2.bankcrisislv12 d.debtToGDP   l.Inflation d.Inflation l.govparty d.govparty if  country!="Denmark" & country!="Sweden" & country!="UK" & country!="Greece", cluster(_ISO3N_)

* A.8 Economic Strikes

eststo D2a: xtreg d.econ_strike l.econ_strike  l.debtToGDP c.l2.bankcrisislv12 d.debtToGDP c.d2.bankcrisislv12  l.Inflation d.Inflation   l.govparty d.govparty , cluster(_ISO3N_)
eststo D2e: xtreg d.econ_strike l.econ_strike  c.l.debtToGDP##c.d2.bankcrisislv12 c.l2.bankcrisislv12 c.d.debtToGDP  l.Inflation d.Inflation   l.govparty d.govparty if year>1995  & country!="Denmark" & country!="Sweden" & country!="UK", cluster(_ISO3N_)
eststo D2f: xtreg d.econ_strike l.econ_strike  c.l.debtToGDP##c.d2.bankcrisislv12 c.l2.bankcrisislv12 c.d.debtToGDP  l.Inflation d.Inflation  l.govparty d.govparty if year>1995 & country=="Denmark" | country=="Sweden" | country=="UK", cluster(_ISO3N_)

*eststo D1a: ivreg econ_strike debtToGDP d.debtToGDP   l.bankcrisislv12 d2.bankcrisislv12 Inflation d.Inflation govparty d.govparty (d.econ_strike = l.econ_strike  debtToGDP l.debtToGDP l.bankcrisislv12 l2.bankcrisislv12 Inflation l.Inflation govparty l.govparty) /*if year>1995 & country!="Denmark" & country!="Sweden" & country!="UK" */
*eststo D1e: ivreg econ_strike debtToGDP d.debtToGDP interaction d.interaction  l.bankcrisislv12 d2.bankcrisislv12 Inflation d.Inflation govparty d.govparty (d.econ_strike = l.econ_strike interaction l.interaction debtToGDP l.debtToGDP  bankcrisislv12 l.bankcrisislv12 l2.bankcrisislv12 Inflation l.Inflation govparty l.govparty) if year>1995 & country!="Denmark" & country!="Sweden" & country!="UK" 
*eststo D1f: ivreg econ_strike debtToGDP d.debtToGDP interaction d.interaction l.bankcrisislv12 d2.bankcrisislv12 Inflation d.Inflation govparty d.govparty (d.econ_strike = l.econ_strike interaction l.interaction debtToGDP l.debtToGDP  bankcrisislv12 l.bankcrisislv12 l2.bankcrisislv12 Inflation l.Inflation govparty l.govparty) if year>1995 & country=="Denmark" | country=="Sweden" | country=="UK" 

*log close
